import { Logger } from '@nestjs/common';
import { NestFactory } from '@nestjs/core';
import { NestExpressApplication } from '@nestjs/platform-express';
import { join } from 'path';
import { AppModule } from './app.module';
import { PREFIX } from './config/router';
import { injectTemplateVars } from './config/template.var';
const { PORT = 4000 } = process.env;

async function bootstrap() {
  const app = await NestFactory.create<NestExpressApplication>(AppModule);
  const logger: Logger = new Logger('main.ts');

  app
    .useStaticAssets(join(process.cwd(), 'public'), { prefix: '/' })
    .setViewEngine('ejs')
    .setBaseViewsDir(join(process.cwd(), 'src/view'))
    .setGlobalPrefix(PREFIX);

  injectTemplateVars(app);

  await app.listen(PORT, () => {
    logger.log(`服务已启动,访问:http://localhost:${PORT}/${PREFIX}`);
  });
}
bootstrap();
